collect_lifecycle_imports

Function collect_lifecycle_imports 

pub fn collect_lifecycle_imports<'a>(
    specs: impl Iterator<Item = &'a LifecycleSpec>,
) -> Option<String>
Collect the @importFrom lifecycle ... roxygen tag needed for a set of lifecycle specs.

This is used by class generators (R6, env, S3, S4, S7) to aggregate lifecycle imports from all methods and include them in the class-level roxygen block. Returns None if no lifecycle imports are needed.