rewrite_external_ptr_receivers

Function rewrite_external_ptr_receivers 

fn rewrite_external_ptr_receivers(item_impl: ItemImpl) -> ItemImpl
Rewrite methods with ExternalPtr-based receivers so they compile on stable Rust (which lacks arbitrary_self_types).

Handles:

  • self: &ExternalPtr<Self>__miniextendr_self: &ExternalPtr<Self>
  • self: &mut ExternalPtr<Self>__miniextendr_self: &mut ExternalPtr<Self>
  • self: ExternalPtr<Self>__miniextendr_self: ExternalPtr<Self>

Also replaces all self references in the method body with __miniextendr_self.