strip_miniextendr_attrs_from_impl

Function strip_miniextendr_attrs_from_impl 

fn strip_miniextendr_attrs_from_impl(item_impl: ItemImpl) -> ItemImpl
Strip #[miniextendr(...)] attributes and roxygen doc tags from an impl block and all of its items (functions, constants, types, macros).

Called before re-emitting the original impl block so that proc-macro attributes do not appear in the compiler output. Returns the cleaned impl block.