validate

Function validate 

pub(crate) fn validate(tokens: &TokenStream) -> Result<(), Error>
Returns Ok(()) if the token stream passes the conservative validator, or an Err spanned to the first problematic token pair/group.