try_lower

Function try_lower 

pub(crate) fn try_lower(
    tail: &TokenStream,
    env_expr: &TokenStream,
) -> Option<TokenStream>
Attempt to lower a validated R tail token stream to a RCall-based TokenStream.

Returns Some(ts) when the tail is fully lowerable; None to signal the caller should emit the r_eval_str string path instead.