try_parse_r_dotname

Function try_parse_r_dotname 

fn try_parse_r_dotname(tokens: &[TokenTree]) -> Option<String>
Try to parse a token sequence as an R dot-separated function name.

Accepts alternating Ident Punct('.') Ident Punct('.') … Ident (odd number of tokens, starting and ending with Ident). Returns the reconstructed name string (e.g. "is.null") or None.