doc_conflict_warnings

Function doc_conflict_warnings 

pub(crate) fn doc_conflict_warnings(
    attrs: &[Attribute],
    _span: Span,
) -> TokenStream
Check for conflicts between explicit @title/@description tags and implicit values.

When the doc-lint feature is enabled, returns tokens that generate compile-time deprecation warnings if explicit roxygen tags differ from the implicit values derived from the doc comment structure.

The returned tokens should be appended to the macro expansion output.