tag_names

Function tag_names 

fn tag_names(tags: &[String]) -> HashSet<&str>
Extract the set of tag names from a list of roxygen tag strings.

Each tag string is expected to start with @tagname. Returns a set of the tag names (without the @ prefix).