pub fn inject_lifecycle_badge(tags: &mut Vec<String>, spec: &LifecycleSpec)Expand description
Inject lifecycle badge into roxygen tags if not already present.
Modifies the tags in place, prepending the badge to @description if present, or adding a new @description tag with just the badge.