pub(crate) fn validate(tokens: &TokenStream) -> Result<(), Error>Expand description
Returns Ok(()) if the token stream passes the conservative validator,
or an Err spanned to the first problematic token pair/group.
pub(crate) fn validate(tokens: &TokenStream) -> Result<(), Error>Returns Ok(()) if the token stream passes the conservative validator,
or an Err spanned to the first problematic token pair/group.