fn needs_fallback(ty: &Type) -> boolExpand description
Returns true if a type is unknown to the static type table and should
be recorded as a fallback parameter.
Returns false for skip types (SEXP, Dots, etc.) and reference types
(which are handled by the static table or skipped).