pub(crate) fn extract_param_names(tags: &[String]) -> HashSet<String>Expand description
Extract the set of parameter names declared via @param in a list of roxygen tags.
For each @param <name> <desc> tag in tags, extracts <name> and inserts it
into the returned HashSet. Used by R6 class generators to build the set of
class-level params so method param loops can suppress (no documentation available)
for names already covered at class level (roxygen2 8.0.0 inherits class-level
@param tags into all methods automatically).