pub(crate) fn find_tag_value<'a>(
tags: &'a [String],
tag_name: &str,
) -> Option<&'a str>Expand description
Find the value of a specific roxygen tag (e.g., “title” for @title ...).
Returns None if the tag is not present or has no value.