pub(crate) fn extract_cfg_attrs(attrs: &[Attribute]) -> Vec<Attribute>Expand description
Extract #[cfg(...)] attributes from a list of attributes.
These should be propagated to generated items so they are conditionally compiled along with the original function.